radish
======

radish is a tool and framework for `BDD (Behavior-driven Development)`_ practicioners
to do BDD for Python based projects.

It aims to make practicing BDD with Python as easy and efficient as possible.


Documentation
-------------

This part of the documentation guides you through all of radish’s usage patterns.

.. toctree::
   :maxdepth: 2

   getting_started
   usage
   syntax
   detail


API Reference
-------------

If you are looking for information on a specific function, class, or
method, this part of the documentation is for you.

.. toctree::
   :maxdepth: 2

   api


ChangeLog
---------

.. toctree::
   :maxdepth: 2

   changelog


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

.. _BDD (Behavior-driven Development): https://en.wikipedia.org/wiki/Behavior-driven_development
